Learn R Programming

genSEIR (version 0.1.1)

SEIQRDP_for_fitting: Fitted Results for SEIQRDP

Description

Fitted Results for SEIQRDP

Usage

SEIQRDP_for_fitting(par, t, t0, Npop, E0, I0, Q, R, D, dt)

Arguments

par

initial guess parameters

t

historical time vector

t0

target time vector

Npop

total population of the country

E0

initial number of exposed cases

I0

initial number of infectious cases

Q

actual number of quarantined cases

R

actual number of recovered cases

D

actual number of dead cases

dt

the time step. This oversamples time to ensure that the algorithm converges

Value

a data frame for fitted quarantined, recovered and deaths

References

Peng, L., Yang, W., Zhang, D., Zhuge, C., Hong, L. 2020. <U+201C>Epidemic analysis of COVID-19 in China by dynamical modeling<U+201D>, arXiv preprint arXiv:2002.06563.

https://www.mathworks.com/matlabcentral/fileexchange/74545-generalized-seir-epidemic-model-fitting-and-computation

See Also

fit_SEIQRDP RK4