Fitted Results for SEIQRDP
SEIQRDP_for_fitting(par, t, t0, Npop, E0, I0, Q, R, D, dt)initial guess parameters
historical time vector
target time vector
total population of the country
initial number of exposed cases
initial number of infectious cases
actual number of quarantined cases
actual number of recovered cases
actual number of dead cases
the time step. This oversamples time to ensure that the algorithm converges
a data frame for fitted quarantined, recovered and deaths
Peng, L., Yang, W., Zhang, D., Zhuge, C., Hong, L. 2020. <U+201C>Epidemic analysis of COVID-19 in China by dynamical modeling<U+201D>, arXiv preprint arXiv:2002.06563.